@@ -344,8 +344,80 @@ key-2: |2-
                    ("key-2" . "  ---\n  ---"))))
   (should (equal (yaml-parse-string "''") ""))
   (should (equal (yaml-parse-string "foo: ''" :object-type 'alist)
-                 '((foo . "")))))
+                 '((foo . ""))))
+  ;; anchor should produce same parse as without anchor
+  (should (equal (yaml-parse-string "bill-to:  &id001
+    city:   East Centerville
+    state:  KS
+" :object-type 'alist
+  :object-key-type 'string
+  :string-values t)
+                 (yaml-parse-string "bill-to:
+    city:   East Centerville
+    state:  KS
+" :object-type 'alist
+  :object-key-type 'string
+  :string-values t)))
+  ;; anchor should expand to be identical to definition
+  (should (equal (yaml-parse-string "bill-to:  &id001
+    street: |
+            123 Tornado Alley
+            Suite 16
+    city:   East Cenrville
+    state:  KS
 
+ship-to:  *id001
+" :object-type 'alist
+  :object-key-type 'string
+  :string-values t)
+                 (yaml-parse-string "bill-to:
+    street: |
+            123 Tornado Alley
+            Suite 16
+    city:   East Cenrville
+    state:  KS
+
+ship-to:
+    street: |
+            123 Tornado Alley
+            Suite 16
+    city:   East Cenrville
+    state:  KS
+
+" :object-type 'alist
+  :object-key-type 'string
+  :string-values t)))
+  (should (equal (progn
+                   (yaml-parse-string-with-pos "- # Empty\n- abc")
+                   (yaml-parse-string "- # Empty\n- abc"))
+                 [:null "abc"]))
+  (should (equal (yaml-parse-string "deeply:\n  nested:\n    value: >-1\n      test string"
+                                    :object-type 'alist)
+                 '((deeply (nested (value . " test string"))))))
+  (should (equal (yaml-parse-string "deeply:\n  nested:\n    value: >-\n      test string"
+                                    :object-type 'alist)
+                 '((deeply (nested (value . "test string"))))))
+  (should (equal (yaml-parse-string "deeply:\n  nested:\n    value: >-2\n      test string"
+                                    :object-type 'alist)
+                 '((deeply (nested (value . "test string"))))))
+  (should (equal (yaml-parse-string "deeply:\n  nested:\n    value: >-7\n           test string"
+                                    :object-type 'alist)
+                 '((deeply (nested (value . "test string"))))))
+  (should (equal (yaml-parse-string "deeply:\n  nested:\n    value: |-6\n           test string"
+                                    :object-type 'alist)
+                 '((deeply (nested (value . " test string"))))))
+  (should (equal (yaml-parse-string "deeply:\n  nested:\n    value: |-\n           test string"
+                                    :object-type 'alist)
+                 '((deeply (nested (value . "test string"))))))
+  (should (equal (yaml-parse-string ">-\n this is text"
+                                    :object-type 'alist)
+                 "this is text"))
+  (should (equal (yaml-parse-string ">-1\n this is text"
+                                    :object-type 'alist)
+                 "this is text"))
+  (should (equal (yaml-parse-string "top: |1\n  this is text"
+                                    :object-type 'alist)
+                 '((top . " this is text\n")))))
 
 (ert-deftest yaml-parsing-completes ()
   "Tests that the yaml parses."
@@ -467,7 +539,8 @@ keep: |+
   (should (yaml-parse-string "\"oarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoar\"
 # beep" :object-type 'alist))
   (should (yaml-parse-string "|\n oarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoaroarsietnaorsetnaorstnearsotnarsoitneiaosretnaoirsetnaorsentaorsentoar
-# beep" :object-type 'alist)))
+# beep" :object-type 'alist))
+  (should (yaml-parse-string "another:\n  value:\n    deeply: >\n      nested" :object-type 'alist)))
 
 
 (defun yaml-test-round-trip (o)
@@ -540,10 +613,30 @@ keep: |+
   (should (equal
            (yaml-encode [1 2 3])
            "[1, 2, 3]"))
+  (should (equal
+           (yaml-encode `[((foo . bar) (baz . bax))])
+           "\n- foo: bar\n  baz: bax"))
+  (should (equal
+           (yaml-encode `((deeper . [((foo . bar) (baz . bax))])))
+           "\ndeeper: \n- foo: bar\n  baz: bax"))
+  (should (equal (yaml-parse-string
+                  (yaml-encode [1 [2 [3] 2] 1])
+                  :object-type 'alist
+                  :sequence-type 'array)
+                 [1 [2 [3] 2] 1]))
+  (should (yaml-test-round-trip `[1 [2 [[4 4 4] 3 ((a . 1) (b . 2) (c . 3)) 3] 2] 1]))
   (should (yaml-test-round-trip
            '((build_the_package (script . "if [ -z \"${CUSTOM}\" ]; then
   ./mvnw package
-fi") (stage . "build"))))))
+fi") (stage . "build")))))
+  (should (yaml-test-round-trip
+           `((deeper . [((foo . bar) (baz . bax))
+                        ((foo . bar) (baz . bax) (bee . bop))])
+             (lower . [((foo . bar) (baz . bax))
+                       ((foo . [((foo . bar) (baz . bax))
+                                ((foo . bar) (baz . bax) (bee . bop))])
+                        (baz . bax)
+                        (bee . bop))])))))
 
 (provide 'yaml-tests)
 
